#!/usr/bin/env python3
import pathlib

import jinja2
import os
from datetime import datetime
import argparse

def timestamp_to_datetime(timestamp):
	return datetime.fromtimestamp(timestamp)

def main(inputfolder, outputfolder, template, ignore_files):
	jinjaenv = jinja2.Environment(autoescape=jinja2.select_autoescape(), loader=jinja2.FileSystemLoader("/usr/local/share/templates"))
	jinjaenv.filters["timestamp_to_datetime"] = timestamp_to_datetime

	template = jinjaenv.get_template(f"{template}.html.j2")

	for path, dirs, files in os.walk(inputfolder):
		dirs.sort()
		files.sort()
		relativ_path_to_input = os.path.relpath(path, inputfolder)
		entries = [(i, os.stat(os.path.join(path, i)), i in dirs) for i in dirs+files if not i in ignore_files]
		html_index = template.render(path=relativ_path_to_input, entries=entries)
		html_index_folder = os.path.join(outputfolder, relativ_path_to_input)
		html_index_path = os.path.join(html_index_folder, 'index.html')
		os.makedirs(html_index_folder, exist_ok=True)
		outputfile = open(html_index_path, "w")
		outputfile.write(html_index)
		outputfile.close()

if __name__ == '__main__':
	parser = argparse.ArgumentParser(description='Create html directory index for given path.')
	parser.add_argument('path', type=pathlib.Path, help='Path to create index from')
	parser.add_argument('output_directory', type=pathlib.Path, help='Directory for generated html files')
	parser.add_argument('--template', help='Template to use without file extension (.html.j2)', default='default')

	args = parser.parse_args()

	main(inputfolder=args.path, outputfolder=args.output_directory, template=args.template, ignore_files=['index.html'])
